complete -c uu-uptime -s s -l since -d 'system up since'
complete -c uu-uptime -s p -l pretty -d 'show uptime in pretty format'
complete -c uu-uptime -s h -l help -d 'Print help'
complete -c uu-uptime -s V -l version -d 'Print version'
