complete -c uu-stty -s F -l file -d 'open and use the specified DEVICE instead of stdin' -r -F
complete -c uu-stty -s a -l all -d 'print all current settings in human-readable form'
complete -c uu-stty -s g -l save -d 'print all current settings in a stty-readable form'
complete -c uu-stty -s h -l help -d 'Print help'
complete -c uu-stty -s V -l version -d 'Print version'
