complete -c uu-mknod -s m -l mode -d 'set file permission bits to MODE, not a=rw - umask' -r
complete -c uu-mknod -l context -d 'like -Z, or if CTX is specified then set the SELinux or SMACK security context to CTX' -r
complete -c uu-mknod -s Z -d 'set SELinux security context of each created directory to the default type'
complete -c uu-mknod -s h -l help -d 'Print help'
complete -c uu-mknod -s V -l version -d 'Print version'
