complete -c uu-cksum -s a -l algorithm -d 'select the digest type to use. See DIGEST below' -r -f -a "sysv\t''
bsd\t''
crc\t''
crc32b\t''
md5\t''
sha1\t''
sha2\t''
sha3\t''
blake2b\t''
sm3\t''
sha224\t''
sha256\t''
sha384\t''
sha512\t''
blake3\t''
shake128\t''
shake256\t''"
complete -c uu-cksum -s l -l length -d 'digest length in bits; must not exceed the max size and must be a multiple of 8 for blake2b; must be 224, 256, 384, or 512 for sha2 or sha3' -r
complete -c uu-cksum -l untagged -d 'create a reversed style checksum, without digest type'
complete -c uu-cksum -l tag -d 'create a BSD style checksum (default)'
complete -c uu-cksum -l raw -d 'emit a raw binary digest, not hexadecimal'
complete -c uu-cksum -s c -l check -d 'read checksums from the FILEs and check them'
complete -c uu-cksum -s w -l warn -d 'warn about improperly formatted checksum lines'
complete -c uu-cksum -l status -d 'don\'t output anything, status code shows success'
complete -c uu-cksum -l quiet -d 'don\'t print OK for each successfully verified file'
complete -c uu-cksum -l ignore-missing -d 'don\'t fail or report status for missing files'
complete -c uu-cksum -l strict -d 'exit non-zero for improperly formatted checksum lines'
complete -c uu-cksum -l base64 -d 'emit base64-encoded digests, not hexadecimal'
complete -c uu-cksum -s t -l text
complete -c uu-cksum -s b -l binary
complete -c uu-cksum -s z -l zero -d 'end each output line with NUL, not newline, and disable file name escaping'
complete -c uu-cksum -l debug -d 'print CPU hardware capability detection info used by cksum'
complete -c uu-cksum -s h -l help -d 'Print help'
complete -c uu-cksum -s V -l version -d 'Print version'
